@@ -69,30 +69,27 @@ TopicModel = R6::R6Class(
       do.call(cbind, res)
     },
     plot = function(lambda.step = 0.1, reorder.topics = FALSE, doc_len = private$doc_len, mds.method = jsPCA_robust, ...) {
-      if("LDAvis" %in% rownames(installed.packages())) {
-        if (!is.null(self$components)) {
-
-          json = LDAvis::createJSON(phi = private$topic_word_distribution_with_prior(),
-                                    theta = private$doc_topic_distribution_with_prior(),
-                                    doc.length = doc_len,
-                                    vocab = private$vocabulary,
-                                    term.frequency = colSums(self$components),
-                                    lambda.step = lambda.step,
-                                    reorder.topics = reorder.topics,
-                                    mds.method = mds.method,
-                                    ...)
-          # modify global option - fixes #181
-          # also we save user encoding and restore it after exit
-          enc = getOption("encoding")
-          on.exit(options(encoding = enc))
-          options(encoding = "UTF-8")
-
-          LDAvis::serVis(json, ...)
-        } else {
-          stop("Model was not fitted, please fit it first...")
-        }
-      } else
+      if (!requireNamespace("LDAvis", quietly = TRUE)) {
         stop("To use visualisation, please install 'LDAvis' package first.")
+      }
+      if (is.null(self$components)) {
+        stop("Model was not fitted, please fit it first...")
+      }
+      json = LDAvis::createJSON(phi = private$topic_word_distribution_with_prior(),
+                                theta = private$doc_topic_distribution_with_prior(),
+                                doc.length = doc_len,
+                                vocab = private$vocabulary,
+                                term.frequency = colSums(self$components),
+                                lambda.step = lambda.step,
+                                reorder.topics = reorder.topics,
+                                mds.method = mds.method,
+                                ...)
+      # modify global option - fixes #181
+      # also we save user encoding and restore it after exit
+      old_opt <- options(encoding = "UTF-8")
+      on.exit(options(old_opt))
+
+      LDAvis::serVis(json, ...)
     }
   ),
   active = list(
@@ -170,7 +167,7 @@ TopicModel = R6::R6Class(
 #'     when one of two following conditions will be satisfied: (a) we have used
 #'     all iterations, or (b) \code{score_previous_check / score_current < 1 + convergence_tol}}}
 #' }
-#' @format \code{\link{R6Class}} object.
+#' @format \code{\link[R6]{R6Class}} object.
 #' @examples
 #' \dontrun{
 #' library(text2vec)
@@ -218,7 +215,7 @@ LatentDirichletAllocation = R6::R6Class(
 
       private$doc_len = rowSums(x)
 
-      private$ptr = warplda_create(n = private$n_topics,
+      private$ptr = warplda_create(n_topics = private$n_topics,
                                    doc_topic_prior = private$doc_topic_prior,
                                    topic_word_prior = private$topic_word_prior)
 
@@ -311,7 +308,7 @@ LatentDirichletAllocation = R6::R6Class(
                          progressbar = interactive(), set_doc_topic_matrix = FALSE, ...) {
       stopifnot(all.equal(colnames(x), private$vocabulary))
       # create model for inferenct (we have to init internal C++ data structures for document-term matrix)
-      inference_model_ptr = warplda_create(n = private$n_topics,
+      inference_model_ptr = warplda_create(n_topics = private$n_topics,
                                            doc_topic_prior = private$doc_topic_prior,
                                            topic_word_prior = private$topic_word_prior)
       private$init_model_dtm(x, inference_model_ptr)
